##--------------------------------------------------------------------------------
## LOAD.POPLARS8.R
## Collation of growth data for native black poplars from 2016 to 2019.
## Acrocephalus Data Services Ltd, 2020-03-25. 
##
## Creates several dataframes for subsequent analysis...
##
## POP1901        field measurements
## TREES          the non-varying data for each tree (source, type etc.)
## POP1901.aug    POP1901 with TREES data joined in
## g2016          growth in 2016 season
## g2017          growth in 2017
## g2018          growth in 2018
## g2019          growth in 2019
##--------------------------------------------------------------------------------

rm(list=objects())

POP2003 <- read.table('MEASUREMENTS.txt', head=T, skip=0, sep='\t')
str(POP2003)
## leave out some of the cols in POP2003, not needed here...
POP2003.ss <- subset(POP2003, select=-c(alive, alive2, leaves, condition, notes))
str(POP2003.ss)

## TREES is the table of non-varying data (source, type, etc)
TREES <- read.table('TREES.txt', head=T, skip=0, sep='\t')
str(TREES)

## database JOIN operation...
POP2003.aug <- merge( x = POP2003.ss, y = TREES, by.x = 'ID', by.y = 'ID')
date.ISO <- as.Date(POP2003.aug$date, format='%d/%m/%Y')
POP2003.aug <- data.frame(POP2003.aug, date.ISO=date.ISO)
POP2003.aug <- subset(POP2003.aug, select=-c(notes))     ## leave out 'notes'
str(POP2003.aug)
POP2003.aug

## year growth data (growth) are stored in separate columns for each year
## (years 2016, 2017...)
vnames.stub <- c('ID', 'type', 'clone', 'mound', 'sex')

## non-NA mesurements for 2016...
vnames <- c(vnames.stub, 'G2016')
ss2016 <- subset(POP2003.aug, !is.na(POP2003.aug$G2016), select = vnames)
g2016 <- cbind(ss2016, year=2016)

vnames <- c(vnames.stub, 'G2017')
ss2017 <- subset(POP2003.aug, !is.na(POP2003.aug$G2017), select = vnames)
g2017 <- cbind(ss2017, year=2017)

vnames <- c(vnames.stub, 'G2018')
ss2018 <- subset(POP2003.aug, !is.na(POP2003.aug$G2018), select = vnames)
g2018 <- cbind(ss2018, year=2018)

vnames <- c(vnames.stub, 'G2019')
ss2019 <- subset(POP2003.aug, !is.na(POP2003.aug$G2019), select = vnames)
g2019 <- cbind(ss2019, year=2019)

vnames.new <- c(ifelse(vnames != 'G2019', vnames, 'growth'), 'year')
## replace 'ID' with 'tree'
vnames.new <- ifelse(vnames.new != 'ID', vnames.new, 'tree')
names(g2016) <- vnames.new
names(g2017) <- vnames.new
names(g2018) <- vnames.new
names(g2019) <- vnames.new
popg <- rbind(g2016, g2017, g2018, g2019)
popg <- data.frame(popg, yearf=factor(popg$year))

## Exclude trees of unknown provenance...
ss1 <- popg[substr(popg[,'type'],1,1) == 'P',]
table(ss1$mound, ss1$year, ss1$type)

## Location plots. x _and_ y must be present...
poploc <- POP2003.aug[!is.na(POP2003.aug$x) & !is.na(POP2003.aug$y),]
poploc
nrow(poploc)
## the most recent location coordinates
lastxy <- by(poploc$date.ISO, list(poploc$ID), max)
as.numeric(lastxy)

poploc.dates <- data.frame(tree = row.names(lastxy), 
    xydate = as.Date(as.numeric(lastxy), origin='1970-01-01'))